@@ -12,7 +12,7 @@ use File::Basename;
 use Digest::MD5 qw(md5_hex);
 use Errno;
 our $AUTOLOAD;
-*VERSION = \'1.4.1.1';
+*VERSION = \'1.4.2';
 
 use constant { OK => 0, WARNING => 1, CRITICAL => 2, UNKNOWN => 3 };
 
@@ -725,9 +725,11 @@ sub number_of_bits {
     'TB' => 8000000000000,	# Terabyte per second, 1,000 gigabytes per second
     # eigene kreationen
     'Bits' => 1,
-    'KBi' => 1024,
-    'MBi' => 1024 * 1024,
-    'GBi' => 1024 * 1024 * 1024,
+    'Bit' => 1,			# Bit per second
+    'KB' => 1024,		# Kilobyte (like disk kilobyte)
+    'KBi' => 1024,		# -"-
+    'MBi' => 1024 * 1024,	# Megabyte (like disk megabyte)
+    'GBi' => 1024 * 1024 * 1024, # Gigybate (like disk gigybyte)
   };
   if (exists $bits->{$unit}) {
     return $bits->{$unit};
@@ -1347,6 +1349,52 @@ sub write_pidfile {
   }
 }
 
+sub system_vartmpdir {
+  my $self = shift;
+  if ($^O =~ /MSWin/) {
+    return $self->system_tmpdir();
+  } else {
+    return "/var/tmp/".$Monitoring::GLPlugin::pluginname;
+  }
+}
+
+sub system_tmpdir {
+  my $self = shift;
+  if ($^O =~ /MSWin/) {
+    return $ENV{TEMP} if defined $ENV{TEMP};
+    return $ENV{TMP} if defined $ENV{TMP};
+    return File::Spec->catfile($ENV{windir}, 'Temp')
+        if defined $ENV{windir};
+    return 'C:\Temp';
+  } else {
+    return "/tmp";
+  }
+}
+
+sub convert_scientific_numbers {
+  my $self = shift;
+  my $n = shift;
+  # mostly used to convert numbers in scientific notation
+  if ($n =~ /^\s*\d+\s*$/) {
+    return $n;
+  } elsif ($n =~ /^\s*([-+]?)(\d*[\.,]*\d*)[eE]{1}([-+]?)(\d+)\s*$/) {
+    my ($vor, $num, $sign, $exp) = ($1, $2, $3, $4);
+    $n =~ s/E/e/g;
+    $n =~ s/,/\./g;
+    $num =~ s/,/\./g;
+    my $sig = $sign eq '-' ? "." . ($exp - 1 + length $num) : '';
+    my $dec = sprintf "%${sig}f", $n;
+    $dec =~ s/\.[0]+$//g;
+    return $dec;
+  } elsif ($n =~ /^\s*([-+]?)(\d+)[\.,]*(\d*)\s*$/) {
+    return $1.$2.".".$3;
+  } elsif ($n =~ /^\s*(.*?)\s*$/) {
+    return $1;
+  } else {
+    return $n;
+  }
+}
+
 sub compatibility_methods {
   my $self = shift;
   # add_perfdata
